import request from '@/utils/request'

// 登录方法
export function usernameLogin(data) {
	return request({
		'url': '/user/login',
		headers: {
			isToken: false
		},
		'method': 'post',
		'data': data
	})
}


// 注册 
export function register (data) {
	return request({
		'url': '/user/register',
		headers: {
			isToken: false
		},
		'method': 'post',
		'data': data
	})
}


// 加载数字校验码图片
export function getCaptchaImage(){
	return request({
		'url': '/user/captcha/image',
		headers: {
			isToken: false
		},
		'method': 'get'
	})
}
// 校验数字校验码
export function checknumberCaptcha(data){
	return request({
		'url': '/user/captcha/verify',
		headers: {
			isToken: false
		},
		'method': 'post',
		data: data
	})
}

// 发送手机验证码
export function smsSend (data) {
	return request({
		'url': '/user/sms/send',
		headers: {
			isToken: false
		},
		'method': 'post',
		'data': data
	})
}
// 手机号码验证登录
export function loginPhone(data){
	return request({
		'url': '/user/login/phone',
		headers: {
			isToken: false
		},
		'method': 'post',
		'data': data
	})
}


// 重置密码
export function resetPwd(data){
	return request({
		url: '/user/resetPassword',
		headers: {
			isToken: false
		},
		'method': 'post',
		'data': data
	})
}


/**
 * 微信登录-获取openId
*/
export function wxLoginOpenid(data){
	return request({
		'url': '/user/wxlogin/getOpenid',
		headers: {
			isToken: false
		},
		'method': 'post',
		'data': data
	})
}

export function wxloginPhone(data){
	return request({
		url: '/user/wxlogin/getPhone',
		headers: {
			isToken: false
		},
		'method': 'post',
		'data': data
	})
}